@@ -24,13 +24,17 @@
 # SOFTWARE.
 import os
 import sys
+from typing import List  # noqa: F401
+
+from .core import base
+from . import config
 
 
 class ConfigError(Exception):
     pass
 
 
-class Config(object):
+class Config:
     settings_keys = [
         "keys",
         "mouse",
@@ -57,6 +61,9 @@ class Config(object):
         Only attributes found in Config.settings_keys will be added to object.
         config attribute precedence is 1.) **settings 2.) self 3.) default_config
         """
+        self.keys = []  # type: List[config.Key]
+        self.mouse = []  # type: List[config.Mouse]
+
         from .resources import default_config
         default = vars(default_config)
         for key in self.settings_keys:
@@ -66,6 +73,7 @@ class Config(object):
                 value = getattr(self, key, default[key])
             setattr(self, key, value)
         self._init_deprecated(**settings)
+        self._init_fake_screens(**settings)
 
     def _init_deprecated(self, extensions=None, **settings):
         "Initialize deprecated settings."
@@ -75,16 +83,43 @@ class Config(object):
                           "'extension_defaults'", DeprecationWarning)
             self.extension_defaults.update(extensions.get('dmenu', {}))
 
+    def _init_fake_screens(self, **settings):
+        " Initiaize fake_screens if they are set."
+        try:
+            value = settings['fake_screens']
+            setattr(self, 'fake_screens', value)
+        except KeyError:
+            pass
+
     @classmethod
-    def from_file(cls, path):
+    def from_file(cls, kore: base.Core, path: str):
         "Create a Config() object from the python file located at path."
         try:
             sys.path.insert(0, os.path.dirname(path))
-            config = __import__(os.path.basename(path)[:-3])
+            config = __import__(os.path.basename(path)[:-3])  # noqa: F811
         except Exception:
             import traceback
             from .log_utils import logger
             logger.exception('Could not import config file %r', path)
             tb = traceback.format_exc()
             raise ConfigError(tb)
-        return cls(**vars(config))
+        cnf = cls(**vars(config))
+        cnf.validate(kore)
+        return cnf
+
+    def validate(self, kore: base.Core) -> None:
+        """
+            Validate the configuration against the core.
+        """
+        valid_keys = kore.get_keys()
+        valid_mods = kore.get_modifiers()
+        for k in self.keys:
+            if k.key not in valid_keys:
+                raise ConfigError("No such key: %s" % k.key)
+            for m in k.modifiers:
+                if m not in valid_mods:
+                    raise ConfigError("No such modifier: %s" % m)
+        for ms in self.mouse:
+            for m in ms.modifiers:
+                if m not in valid_mods:
+                    raise ConfigError("No such modifier: %s" % m)
