@@ -17,9 +17,6 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-
-from __future__ import division
-
 import array
 import contextlib
 import inspect
@@ -155,14 +152,14 @@ def _float_setter(attr):
 
 
 class _Window(command.CommandObject):
-    _windowMask = 0  # override in child class
+    _window_mask = 0  # override in child class
 
     def __init__(self, window, qtile):
         self.window, self.qtile = window, qtile
         self.hidden = True
         self.group = None
         self.icons = {}
-        window.set_attribute(eventmask=self._windowMask)
+        window.set_attribute(eventmask=self._window_mask)
 
         self._float_info = {
             'x': None,
@@ -210,7 +207,7 @@ class _Window(command.CommandObject):
             'base_width': 0,
             'base_height': 0,
         }
-        self.updateHints()
+        self.update_hints()
 
     x = property(fset=_geometry_setter("x"), fget=_geometry_getter("x"))
     y = property(fset=_geometry_setter("y"), fget=_geometry_getter("y"))
@@ -250,16 +247,16 @@ class _Window(command.CommandObject):
 
     @property
     def has_focus(self):
-        return self == self.qtile.currentWindow
+        return self == self.qtile.current_window
 
-    def updateName(self):
+    def update_name(self):
         try:
             self.name = self.window.get_name()
         except (xcffib.xproto.WindowError, xcffib.xproto.AccessError):
             return
         hook.fire('client_name_updated', self)
 
-    def updateHints(self):
+    def update_hints(self):
         """Update the local copy of the window's WM_HINTS
 
         See http://tronche.com/gui/x/icccm/sec-4.html#WM_HINTS
@@ -310,7 +307,7 @@ class _Window(command.CommandObject):
             self.hints.update(normh)
 
         if h and 'UrgencyHint' in h['flags']:
-            if self.qtile.currentWindow != self:
+            if self.qtile.current_window != self:
                 self.hints['urgent'] = True
                 hook.fire('client_urgent_hint_changed', self)
         elif self.urgent:
@@ -318,11 +315,11 @@ class _Window(command.CommandObject):
             hook.fire('client_urgent_hint_changed', self)
 
         if getattr(self, 'group', None):
-            self.group.layoutAll()
+            self.group.layout_all()
 
         return
 
-    def updateState(self):
+    def update_state(self):
         triggered = ['urgent']
 
         if self.qtile.config.auto_fullscreen:
@@ -374,14 +371,14 @@ class _Window(command.CommandObject):
         if val in (WithdrawnState, NormalState, IconicState):
             self.window.set_property('WM_STATE', [val, 0])
 
-    def setOpacity(self, opacity):
+    def set_opacity(self, opacity):
         if 0.0 <= opacity <= 1.0:
             real_opacity = int(opacity * 0xffffffff)
             self.window.set_property('_NET_WM_WINDOW_OPACITY', real_opacity)
         else:
             return
 
-    def getOpacity(self):
+    def get_opacity(self):
         opacity = self.window.get_property(
             "_NET_WM_WINDOW_OPACITY", unpack=int
         )
@@ -393,7 +390,7 @@ class _Window(command.CommandObject):
             as_float = round(value / 0xffffffff, 2)
             return as_float
 
-    opacity = property(getOpacity, setOpacity)
+    opacity = property(get_opacity, set_opacity)
 
     def kill(self):
         if "WM_DELETE_WINDOW" in self.window.get_wm_protocols():
@@ -421,7 +418,7 @@ class _Window(command.CommandObject):
 
     def hide(self):
         # We don't want to get the UnmapNotify for this unmap
-        with self.disableMask(xcffib.xproto.EventMask.StructureNotify):
+        with self.disable_mask(xcffib.xproto.EventMask.StructureNotify):
             self.window.unmap()
         self.hidden = True
 
@@ -431,19 +428,19 @@ class _Window(command.CommandObject):
         self.hidden = False
 
     @contextlib.contextmanager
-    def disableMask(self, mask):
-        self._disableMask(mask)
+    def disable_mask(self, mask):
+        self._disable_mask(mask)
         yield
-        self._resetMask()
+        self._reset_mask()
 
-    def _disableMask(self, mask):
+    def _disable_mask(self, mask):
         self.window.set_attribute(
-            eventmask=self._windowMask & (~mask)
+            eventmask=self._window_mask & (~mask)
         )
 
-    def _resetMask(self):
+    def _reset_mask(self):
         self.window.set_attribute(
-            eventmask=self._windowMask
+            eventmask=self._window_mask
         )
 
     def place(self, x, y, width, height, borderwidth, bordercolor,
@@ -655,7 +652,7 @@ class _Window(command.CommandObject):
 
 class Internal(_Window):
     """An internal window, that should not be managed by qtile"""
-    _windowMask = EventMask.StructureNotify | \
+    _window_mask = EventMask.StructureNotify | \
         EventMask.PropertyChange | \
         EventMask.EnterWindow | \
         EventMask.FocusChange | \
@@ -685,7 +682,7 @@ class Internal(_Window):
 
 class Static(_Window):
     """An internal window, that should not be managed by qtile"""
-    _windowMask = EventMask.StructureNotify | \
+    _window_mask = EventMask.StructureNotify | \
         EventMask.PropertyChange | \
         EventMask.EnterWindow | \
         EventMask.FocusChange | \
@@ -694,7 +691,7 @@ class Static(_Window):
     def __init__(self, win, qtile, screen,
                  x=None, y=None, width=None, height=None):
         _Window.__init__(self, win, qtile)
-        self.updateName()
+        self.update_name()
         self.conf_x = x
         self.conf_y = y
         self.conf_width = width
@@ -708,7 +705,7 @@ class Static(_Window):
             self.place(x, y, width, height, 0, 0)
         self.update_strut()
 
-    def handle_ConfigureRequest(self, e):
+    def handle_ConfigureRequest(self, e):  # noqa: N802
         cw = xcffib.xproto.ConfigWindow
         if self.conf_x is None and e.value_mask & cw.X:
             self.x = e.x
@@ -742,7 +739,7 @@ class Static(_Window):
         self.qtile.update_gaps(strut, self.strut)
         self.strut = strut
 
-    def handle_PropertyNotify(self, e):
+    def handle_PropertyNotify(self, e):  # noqa: N802
         name = self.qtile.conn.atoms.get_name(e.atom)
         if name in ("_NET_WM_STRUT_PARTIAL", "_NET_WM_STRUT"):
             self.update_strut()
@@ -752,7 +749,7 @@ class Static(_Window):
 
 
 class Window(_Window):
-    _windowMask = EventMask.StructureNotify | \
+    _window_mask = EventMask.StructureNotify | \
         EventMask.PropertyChange | \
         EventMask.EnterWindow | \
         EventMask.FocusChange
@@ -762,7 +759,7 @@ class Window(_Window):
     def __init__(self, window, qtile):
         _Window.__init__(self, window, qtile)
         self._group = None
-        self.updateName()
+        self.update_name()
         # add to group by position according to _NET_WM_DESKTOP property
         group = None
         index = window.get_wm_desktop()
@@ -770,13 +767,13 @@ class Window(_Window):
             group = qtile.groups[index]
         elif index is None:
             transient_for = window.get_wm_transient_for()
-            win = qtile.windowMap.get(transient_for)
+            win = qtile.windows_map.get(transient_for)
             if win is not None:
                 group = win._group
         if group is not None:
             group.add(self)
             self._group = group
-            if group != qtile.currentScreen.group:
+            if group != qtile.current_screen.group:
                 self.hide()
 
         # add window to the save-set, so it gets mapped when qtile dies
@@ -952,13 +949,12 @@ class Window(_Window):
         if self.group:
             self.group.remove(self)
         s = Static(self.window, self.qtile, screen, x, y, width, height)
-        self.qtile.windowMap[self.window.wid] = s
+        self.qtile.windows_map[self.window.wid] = s
         hook.fire("client_managed", s)
         return s
 
     def tweak_float(self, x=None, y=None, dx=0, dy=0,
                     w=None, h=None, dw=0, dh=0):
-        print(x, y)
         if x is not None:
             self.x = x
         self.x += dx
@@ -984,7 +980,7 @@ class Window(_Window):
         if self.group and screen is not None and screen != self.group.screen:
             self.group.remove(self, force=True)
             screen.group.add(self, force=True)
-            self.qtile.toScreen(screen.index)
+            self.qtile.focus_screen(screen.index)
 
         self._reconfigure_floating()
 
@@ -1008,7 +1004,6 @@ class Window(_Window):
             if self.hints['base_height'] and self.hints['height_inc']:
                 height -= (height - self.hints['base_height']) % self.hints['height_inc']
 
-            print("placing", self.x, self.y, width, height)
             self.place(
                 self.x, self.y,
                 width, height,
@@ -1031,14 +1026,14 @@ class Window(_Window):
             self.height = h
         self._reconfigure_floating(new_float_state=new_float_state)
 
-    def togroup(self, groupName=None):
+    def togroup(self, group_name=None):
         """Move window to a specified group"""
-        if groupName is None:
-            group = self.qtile.currentGroup
+        if group_name is None:
+            group = self.qtile.current_group
         else:
-            group = self.qtile.groupMap.get(groupName)
+            group = self.qtile.groups_map.get(group_name)
             if group is None:
-                raise command.CommandError("No such group: %s" % groupName)
+                raise command.CommandError("No such group: %s" % group_name)
 
         if self.group is not group:
             self.hide()
@@ -1055,7 +1050,7 @@ class Window(_Window):
     def toscreen(self, index=None):
         """ Move window to a specified screen, or the current screen. """
         if index is None:
-            screen = self.qtile.currentScreen
+            screen = self.qtile.current_screen
         else:
             try:
                 screen = self.qtile.screens[index]
@@ -1096,19 +1091,19 @@ class Window(_Window):
 
         return False
 
-    def handle_EnterNotify(self, e):
+    def handle_EnterNotify(self, e):  # noqa: N802
         hook.fire("client_mouse_enter", self)
         if self.qtile.config.follow_mouse_focus and \
-                self.group.currentWindow != self:
+                self.group.current_window != self:
             self.group.focus(self, False)
         if self.group.screen and \
-                self.qtile.currentScreen != self.group.screen and \
+                self.qtile.current_screen != self.group.screen and \
                 self.qtile.config.follow_mouse_focus:
-            self.qtile.toScreen(self.group.screen.index, False)
+            self.qtile.focus_screen(self.group.screen.index, False)
         return True
 
-    def handle_ConfigureRequest(self, e):
-        if self.qtile._drag and self.qtile.currentWindow == self:
+    def handle_ConfigureRequest(self, e):  # noqa: N802
+        if self.qtile._drag and self.qtile.current_window == self:
             # ignore requests while user is dragging window
             return
         if getattr(self, 'floating', False):
@@ -1127,7 +1122,7 @@ class Window(_Window):
                 width, height,
                 self.borderwidth, self.bordercolor,
             )
-        self.updateState()
+        self.update_state()
         return False
 
     def update_wm_net_icon(self):
@@ -1165,7 +1160,7 @@ class Window(_Window):
         self.icons = icons
         hook.fire("net_wm_icon_change", self)
 
-    def handle_ClientMessage(self, event):
+    def handle_ClientMessage(self, event):  # noqa: N802
         atoms = self.qtile.conn.atoms
 
         opcode = event.type
@@ -1197,17 +1192,17 @@ class Window(_Window):
             source = data.data32[0]
             if source == 2:  # XCB_EWMH_CLIENT_SOURCE_TYPE_NORMAL
                 logger.info("Focusing window by pager")
-                self.qtile.currentScreen.setGroup(self.group)
+                self.qtile.current_screen.set_group(self.group)
                 self.group.focus(self)
             else:  # XCB_EWMH_CLIENT_SOURCE_TYPE_OTHER
                 focus_behavior = self.qtile.config.focus_on_window_activation
                 if focus_behavior == "focus":
                     logger.info("Focusing window")
-                    self.qtile.currentScreen.setGroup(self.group)
+                    self.qtile.current_screen.set_group(self.group)
                     self.group.focus(self)
-                elif focus_behavior == "smart" and self.group.screen and self.group.screen == self.qtile.currentScreen:
+                elif focus_behavior == "smart" and self.group.screen and self.group.screen == self.qtile.current_screen:
                     logger.info("Focusing window")
-                    self.qtile.currentScreen.setGroup(self.group)
+                    self.qtile.current_screen.set_group(self.group)
                     self.group.focus(self)
                 elif focus_behavior == "urgent" or (focus_behavior == "smart" and not self.group.screen):
                     logger.info("Setting urgent flag for window")
@@ -1215,21 +1210,21 @@ class Window(_Window):
                 else:
                     logger.info("Ignoring focus request")
 
-    def handle_PropertyNotify(self, e):
+    def handle_PropertyNotify(self, e):  # noqa: N802
         name = self.qtile.conn.atoms.get_name(e.atom)
         logger.debug("PropertyNotifyEvent: %s", name)
         if name == "WM_TRANSIENT_FOR":
             pass
         elif name == "WM_HINTS":
-            self.updateHints()
+            self.update_hints()
         elif name == "WM_NORMAL_HINTS":
-            self.updateHints()
+            self.update_hints()
         elif name == "WM_NAME":
-            self.updateName()
+            self.update_name()
         elif name == "_NET_WM_NAME":
-            self.updateName()
+            self.update_name()
         elif name == "_NET_WM_VISIBLE_NAME":
-            self.updateName()
+            self.update_name()
         elif name == "WM_ICON_NAME":
             pass
         elif name == "_NET_WM_ICON_NAME":
@@ -1243,18 +1238,18 @@ class Window(_Window):
         elif name == "WM_STATE":
             pass
         elif name == "_NET_WM_STATE":
-            self.updateState()
+            self.update_state()
         elif name == "WM_PROTOCOLS":
             pass
         elif name == "_NET_WM_DESKTOP":
             # Some windows set the state(fullscreen) when starts,
-            # updateState is here because the group and the screen
+            # update_state is here because the group and the screen
             # are set when the property is emitted
-            # self.updateState()
-            self.updateState()
+            # self.update_state()
+            self.update_state()
         elif name == "_NET_WM_USER_TIME":
             if not self.qtile.config.follow_mouse_focus and \
-                    self.group.currentWindow != self:
+                    self.group.current_window != self:
                 self.group.focus(self, False)
         else:
             logger.info("Unknown window property: %s", name)
@@ -1293,7 +1288,7 @@ class Window(_Window):
         """
         self.kill()
 
-    def cmd_togroup(self, groupName=None):
+    def cmd_togroup(self, groupName=None):  # noqa: 803
         """Move window to a specified group.
 
         If groupName is not specified, we assume the current group
@@ -1434,5 +1429,5 @@ class Window(_Window):
                 index2 = clients.index(window)
                 clients[index1], clients[index2] = clients[index2], clients[index1]
                 self.group.layout.focused = index2
-                self.group.layoutAll()
+                self.group.layout_all()
                 break
